library iws_device_info;

import 'package:iws_device_info/src/device_service.dart';

import 'src/device_model.dart';

export 'src/device_model.dart';

class IwsDeviceInfo {
  /// Retrieves the platform name of the device.
  ///
  /// Returns:
  ///   - `PlatformName?`: The platform name of the device, or `null` if the platform name
  ///     cannot be determined.
  static PlatformName? getDevicePlatformName() =>
      DeviceService.getDevicePlatformName();

  /// Retrieves the device information for a given device ID and user identifier.
  ///
  /// Parameters:
  ///   - deviceId: The ID of the device to retrieve information for.
  ///   - userIdentifier: (optional) The user identifier associated with the device.
  ///
  /// Returns:
  ///   - A `Future` that resolves to an `AppDevice` object containing the device information.
  static Future<AppDevice> getDeviceInfo(
          {required String deviceId, String? userIdentifier}) =>
      DeviceService.getDeviceInfo(
          deviceId: deviceId, userIdentifier: userIdentifier);
}
